@@ -268,7 +268,7 @@ class AliveHandler(BaseHandler):
 class LBCSServer(tornado.web.Application):
     def __init__(self, cfg: config.LBCSConfig, leds: Dict[int, int], led_index_mapping: Dict[int, int]):
         pixels = neopixel.NeoPixel(
-            getattr(board, cfg.pixel_pin), len(leds), brightness=1, auto_write=False
+            getattr(board, cfg.pixel_pin), len(leds) * 2, brightness=1, auto_write=False
         )
         q: Queue = Queue()
 
@@ -306,6 +306,7 @@ def main():
     logger.info(f"Parsed server config\n{cfg.pretty()}\n")
     logger.info(f"Starting Little Bull Climbing Server server on port {cfg.port}")
     tornado.ioloop.IOLoop.current().start()
+    logger.info("Little Bull Climbing Server server ready to accept requests")
 
 
 if __name__ == "__main__":
